@@ -12,7 +12,7 @@
 
 #include <QVariant>
 
-addPoComment::addPoComment(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
+addPoComment::addPoComment(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
     : XDialog(parent, name, modal, fl)
 {
   setupUi(this);
