@@ -19,7 +19,7 @@ class addresses : public display
     Q_OBJECT
 
 public:
-    addresses(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    addresses(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
 public slots:
     virtual void sPopulateMenu(QMenu *, QTreeWidgetItem* = NULL, int = 0);
