@@ -22,7 +22,7 @@ class apOpenItem : public XDialog, public Ui::apOpenItem
     Q_OBJECT
 
 public:
-    apOpenItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    apOpenItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~apOpenItem();
 
     virtual void populate();
