@@ -33,7 +33,7 @@ class apWorkBench : public XWidget, public Ui::apWorkBench
     Q_OBJECT
 
   public:
-    apWorkBench(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    apWorkBench(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~apWorkBench();
 
     virtual SetResponse set(const ParameterList & pParams);
