@@ -22,7 +22,7 @@ class applyARDiscount : public XDialog, public Ui::applyARDiscount
     Q_OBJECT
 
   public:
-    applyARDiscount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    applyARDiscount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~applyARDiscount();
 
   public slots:
