@@ -22,7 +22,7 @@ class arCreditMemoApplication : public XDialog, public Ui::arCreditMemoApplicati
     Q_OBJECT
 
 public:
-    arCreditMemoApplication(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    arCreditMemoApplication(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~arCreditMemoApplication();
 
 public slots:
