@@ -21,7 +21,7 @@ class assignClassCodeToPlannerCode : public XDialog, public Ui::assignClassCodeT
     Q_OBJECT
 
 public:
-    assignClassCodeToPlannerCode(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    assignClassCodeToPlannerCode(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~assignClassCodeToPlannerCode();
 
 public slots:
