@@ -15,7 +15,7 @@
 #include <QValidator>
 #include <QVariant>
 
-bankAccount::bankAccount(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
+bankAccount::bankAccount(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
     : XDialog(parent, name, modal, fl)
 {
   setupUi(this);
@@ -38,7 +38,7 @@ bankAccount::bankAccount(QWidget* parent, const char* name, bool modal, Qt::WFla
   _currency->setType(XComboBox::Currencies);
   _currency->setLabel(_currencyLit);
 
-  _form->setAllowNull(TRUE);
+  _form->setAllowNull(true);
   _form->populate( "SELECT form_id, form_name, form_name "
                    "FROM form "
                    "WHERE form_key='Chck' "
@@ -104,23 +104,24 @@ enum SetResponse bankAccount::set(const ParameterList &pParams)
     else if (param.toString() == "edit")
     {
       _mode = cEdit;
-      _currency->setEnabled(FALSE);
+      _currency->setEnabled(false);
     }
     else if (param.toString() == "view")
     {
       _mode = cView;
 
-      _name->setEnabled(FALSE);
-      _description->setEnabled(FALSE);
-      _bankName->setEnabled(FALSE);
-      _accountNumber->setEnabled(FALSE);
-      _type->setEnabled(FALSE);
-      _currency->setEnabled(FALSE);
-      _ap->setEnabled(FALSE);
-      _nextCheckNum->setEnabled(FALSE);
-      _form->setEnabled(FALSE);
-      _ar->setEnabled(FALSE);
-      _assetAccount->setReadOnly(TRUE);
+      _name->setEnabled(false);
+      _description->setEnabled(false);
+      _bankName->setEnabled(false);
+      _accountNumber->setEnabled(false);
+      _type->setEnabled(false);
+      _currency->setEnabled(false);
+      _ap->setEnabled(false);
+      _nextCheckNum->setEnabled(false);
+      _printCheck->setEnabled(false);
+      _form->setEnabled(false);
+      _ar->setEnabled(false);
+      _assetAccount->setReadOnly(true);
       _buttonBox->clear();
       _buttonBox->addButton(QDialogButtonBox::Close);
     }
@@ -146,7 +147,7 @@ void bankAccount::sCheck()
       _mode = cEdit;
       populate();
 
-      _name->setEnabled(FALSE);
+      _name->setEnabled(false);
     }
     else if (bankCheck.lastError().type() != QSqlError::NoError)
     {
@@ -304,7 +305,8 @@ void bankAccount::sSave()
                "  bankaccnt_ach_originname, bankaccnt_ach_origin,"
                "  bankaccnt_ach_desttype, bankaccnt_ach_fed_dest,"
                "  bankaccnt_ach_destname, bankaccnt_ach_dest,"
-               "  bankaccnt_ach_genchecknum, bankaccnt_ach_leadtime)"
+               "  bankaccnt_ach_genchecknum, bankaccnt_ach_leadtime,"
+               "  bankaccnt_prnt_check)"
                "VALUES "
                "( :bankaccnt_id, :bankaccnt_name, :bankaccnt_descrip,"
                "  :bankaccnt_bankname, :bankaccnt_accntnumber,"
@@ -316,7 +318,8 @@ void bankAccount::sSave()
                "  :bankaccnt_ach_originname, :bankaccnt_ach_origin,"
                "  :bankaccnt_ach_desttype, :bankaccnt_ach_fed_dest,"
                "  :bankaccnt_ach_destname, :bankaccnt_ach_dest,"
-               "  :bankaccnt_ach_genchecknum, :bankaccnt_ach_leadtime);" );
+               "  :bankaccnt_ach_genchecknum, :bankaccnt_ach_leadtime,"
+               "  :bankaccnt_prnt_check);" );
   }
   else if (_mode == cEdit)
     bankSave.prepare( "UPDATE bankaccnt "
@@ -342,7 +345,8 @@ void bankAccount::sSave()
                "    bankaccnt_ach_destname=:bankaccnt_ach_destname,"
                "    bankaccnt_ach_dest=:bankaccnt_ach_dest,"
                "    bankaccnt_ach_genchecknum=:bankaccnt_ach_genchecknum,"
-               "    bankaccnt_ach_leadtime=:bankaccnt_ach_leadtime "
+               "    bankaccnt_ach_leadtime=:bankaccnt_ach_leadtime, "
+               "    bankaccnt_prnt_check=:bankaccnt_prnt_check "
                "WHERE (bankaccnt_id=:bankaccnt_id);" );
   
   bankSave.bindValue(":bankaccnt_id",          _bankaccntid);
@@ -351,6 +355,7 @@ void bankAccount::sSave()
   bankSave.bindValue(":bankaccnt_bankname",    _bankName->text());
   bankSave.bindValue(":bankaccnt_accntnumber", _accountNumber->text());
   bankSave.bindValue(":bankaccnt_ap",          QVariant(_ap->isChecked()));
+  bankSave.bindValue(":bankaccnt_prnt_check",  QVariant(_printCheck->isChecked()));
   bankSave.bindValue(":bankaccnt_ar",          QVariant(_ar->isChecked()));
   bankSave.bindValue(":bankaccnt_accnt_id",    _assetAccount->id());
   bankSave.bindValue(":bankaccnt_curr_id",     _currency->id());
@@ -415,6 +420,7 @@ void bankAccount::populate()
     _bankName->setText(bankpopulate.value("bankaccnt_bankname"));
     _accountNumber->setText(bankpopulate.value("bankaccnt_accntnumber"));
     _ap->setChecked(bankpopulate.value("bankaccnt_ap").toBool());
+    _printCheck->setChecked(bankpopulate.value("bankaccnt_prnt_check").toBool());
     _ar->setChecked(bankpopulate.value("bankaccnt_ar").toBool());
     _nextCheckNum->setText(bankpopulate.value("bankaccnt_nextchknum"));
     _form->setId(bankpopulate.value("bankaccnt_check_form_id").toInt());
