@@ -21,7 +21,7 @@ class bomList : public XWidget, public Ui::bomList
     Q_OBJECT
 
 public:
-    bomList(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    bomList(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~bomList();
 
 public slots:
