@@ -22,7 +22,7 @@ class cashReceiptMiscDistrib : public XDialog, public Ui::cashReceiptMiscDistrib
     Q_OBJECT
 
 public:
-    cashReceiptMiscDistrib(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    cashReceiptMiscDistrib(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~cashReceiptMiscDistrib();
 
 public slots:
