@@ -22,7 +22,7 @@ class changePoitemQty : public XDialog, public Ui::changePoitemQty
     Q_OBJECT
 
 public:
-    changePoitemQty(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    changePoitemQty(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~changePoitemQty();
 
 public slots:
