@@ -25,7 +25,7 @@ class configureCC : public XAbstractConfigure, public Ui::configureCC
     Q_OBJECT
 
 public:
-    configureCC(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    configureCC(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~configureCC();
 
 public slots:
