@@ -22,7 +22,7 @@
 #include "itemSite.h"
 #include "storedProcErrorLookup.h"
 
-copyItem::copyItem(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
+copyItem::copyItem(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
     : XDialog(parent, name, modal, fl)
 {
   setupUi(this);
@@ -56,8 +56,8 @@ copyItem::copyItem(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
   _listCost->setValidator(omfgThis->costVal());
 
   _newitemid = -1;
-  _inTransaction = FALSE;
-  _captive = FALSE;
+  _inTransaction = false;
+  _captive = false;
 }
 
 copyItem::~copyItem()
@@ -73,7 +73,7 @@ void copyItem::languageChange()
 enum SetResponse copyItem::set(const ParameterList &pParams)
 {
   XDialog::set(pParams);
-  _captive = TRUE;
+  _captive = true;
 
   QVariant param;
   bool     valid;
@@ -82,7 +82,7 @@ enum SetResponse copyItem::set(const ParameterList &pParams)
   if (valid)
   {
     _source->setId(param.toInt());
-    _source->setEnabled(FALSE);
+    _source->setEnabled(false);
   }
 
   return NoError;
@@ -90,19 +90,49 @@ enum SetResponse copyItem::set(const ParameterList &pParams)
 
 void copyItem::sSaveItem()
 {
+  if(_source->id() == -1)
+    return;
+
   XSqlQuery itemsave;
   if(_inTransaction)
-    return;
+    itemsave.exec("ROLLBACK;");
+  else
+    _inTransaction = true;
   
-  _inTransaction = true;
+  //Find an unused temporary item number
+  int tempCopyint = 0;
+  while (true)
+  {
+    itemsave.prepare("SELECT sourceitemnumber AS result "
+                     "FROM item,"
+                     " (SELECT item_number AS sourceitemnumber"
+                     "  FROM item"
+                     "  WHERE item_id=:sourceitemid) AS data "
+                     "WHERE (item_number = ('TEMPCOPY' || :tempcopyint::TEXT || sourceitemnumber));");
+    itemsave.bindValue(":sourceitemid", _source->id());
+    itemsave.bindValue(":tempcopyint", tempCopyint);
+    itemsave.exec();
+    if (itemsave.lastError().type() != QSqlError::NoError)
+    {
+      _inTransaction = false;
+      return;
+    }
+    if(!itemsave.first())
+    {
+      break;
+    }
+    tempCopyint = tempCopyint + 1;
+  }
+
   itemsave.exec("BEGIN;");
   
-  itemsave.prepare("SELECT copyItem(item_id, 'TEMPCOPY' || :sourceitemnumber) AS result,"
+  itemsave.prepare("SELECT copyItem(item_id, 'TEMPCOPY' || :tempcopyint::TEXT || :sourceitemnumber) AS result,"
                    "       item_descrip1, item_listprice, item_listcost "
                    "FROM item "
                    "WHERE (item_id=:sourceitemid);");
   itemsave.bindValue(":sourceitemid", _source->id());
   itemsave.bindValue(":sourceitemnumber", _source->number());
+  itemsave.bindValue(":tempcopyint", tempCopyint);
   itemsave.exec();
   if(itemsave.first())
   {
@@ -127,7 +157,7 @@ void copyItem::sCopyBom()
   if (_copyBOM->isChecked())
   {
     XSqlQuery bomitemq;
-    bomitemq.prepare("SELECT copyBom(:sourceitemid, :targetitemid, TRUE) AS result;");
+    bomitemq.prepare("SELECT copyBom(:sourceitemid, :targetitemid, true) AS result;");
     bomitemq.bindValue(":sourceitemid", _source->id());
     bomitemq.bindValue(":targetitemid", _newitemid);
     bomitemq.exec();
@@ -151,6 +181,12 @@ void copyItem::sCopyBom()
 
 void copyItem::sAddBomitem()
 {
+  if (_newitemid == -1)
+  {
+    QMessageBox::critical(this, tr("Error"), tr("Please enter a Source Item."));
+    return;
+  }
+  
   if (_availablebomitems->id() == -1)
   {
     QMessageBox::critical(this, tr("Error"), tr("Please select an Available BOM Item."));
@@ -160,7 +196,7 @@ void copyItem::sAddBomitem()
   XSqlQuery bomitemq;
   int uomid;
   QString uomname;
-  double qtyper;
+  double qtyper = 1.0;
   bool ok;
   
   bomitemq.prepare("SELECT item_inv_uom_id, uom_name "
@@ -196,11 +232,11 @@ void copyItem::sAddBomitem()
                    "   :targetitemid, (MAX(bomitem_seqnumber) + 10),"
                    "   :bomitemid, :qtyper, 0.0,"
                    "   NULL, startOfTime(), endOfTime(),"
-                   "   FALSE, 'M', TRUE,"
+                   "   false, 'M', true,"
                    "   NULL, CURRENT_DATE, 'I',"
                    "   :uomid, -1, -1,"
                    "   NULL, NULL, NULL,"
-                   "   NULL, 0.0, FALSE "
+                   "   NULL, 0.0, false "
                    " FROM bomitem "
                    " WHERE (bomitem_parent_item_id=:targetitemid);" );
   bomitemq.bindValue(":targetitemid", _newitemid);
@@ -217,11 +253,17 @@ void copyItem::sAddBomitem()
 
 void copyItem::sEditBomitem()
 {
+  if (_addedbomitems->id() == -1)
+  {
+    QMessageBox::critical(this, tr("Error"), tr("Please select a Component Item."));
+    return;
+  }
+  
   ParameterList params;
   params.append("mode", "edit");
   params.append("bomitem_id", _addedbomitems->id());
   
-  bomItem newdlg(this, "", TRUE);
+  bomItem newdlg(this, "", true);
   newdlg.set(params);
   newdlg.exec();
   
@@ -256,9 +298,10 @@ void copyItem::sFillItem()
   XSqlQuery bomitemq;
   bomitemq.prepare("SELECT item_id, item_number, itemalias_number, item_descrip1 "
                    "FROM item LEFT OUTER JOIN itemalias ON (itemalias_item_id=item_id) "
-                   "WHERE (item_number ~* :searchfor)"
-                   "   OR (itemalias_number ~* :searchfor)"
-                   "   OR (item_descrip1 ~* :searchfor);");
+                   "WHERE ( (item_number ~* :searchfor) OR"
+                   "        (itemalias_number ~* :searchfor) OR"
+                   "        (item_descrip1 ~* :searchfor) )"
+                   "  AND (item_active OR fetchMetricBool('AllowInactiveBomItems'));");
   bomitemq.bindValue(":searchfor", _searchForBOM->text());
   bomitemq.exec();
   if (ErrorReporter::error(QtCriticalMsg, this, tr("Filling Bomitem"),
@@ -299,6 +342,19 @@ void copyItem::sFillBomitem()
       _listCost->setDouble(bomitemq.value("listcost").toDouble());
     }
   }
+  else
+  {
+    bomitemq.prepare("SELECT item_listprice, item_listcost "
+                     "FROM item "
+                     "WHERE (item_id=:sourceitemid);");
+    bomitemq.bindValue(":sourceitemid", _source->id());
+    bomitemq.exec();
+    if(bomitemq.first())
+    {
+      _listPrice->setDouble(bomitemq.value("item_listprice").toDouble());
+      _listCost->setDouble(bomitemq.value("item_listcost").toDouble());
+    }
+  }
 }
 
 void copyItem::sCopyItemsite()
@@ -307,8 +363,8 @@ void copyItem::sCopyItemsite()
   {
     XSqlQuery itemsiteq;
     itemsiteq.prepare("SELECT copyItemsite(itemsite_id, itemsite_warehous_id, :targetitemid) AS result FROM "
-                      "(SELECT * "
-                      " FROM itemsite JOIN whsinfo ON (warehous_id=itemsite_warehous_id) "
+                      "(SELECT itemsite_id, itemsite_warehous_id"
+                      "  FROM itemsite JOIN whsinfo ON (warehous_id=itemsite_warehous_id) "
                       " WHERE (itemsite_item_id=:sourceitemid) "
                       " ORDER BY warehous_sequence DESC) AS data;");
     itemsiteq.bindValue(":sourceitemid", _source->id());
@@ -357,7 +413,7 @@ void copyItem::sAddItemsite()
     params.append("mode", "edit");
     params.append("itemsite_id", result);
     
-    itemSite newdlg(this, "", TRUE);
+    itemSite newdlg(this, "", true);
     newdlg.set(params);
     if (newdlg.exec() != XDialog::Accepted)
     {
@@ -394,7 +450,7 @@ void copyItem::sEditItemsite()
   params.append("mode", "edit");
   params.append("itemsite_id", _addeditemsites->id());
   
-  itemSite newdlg(this, "", TRUE);
+  itemSite newdlg(this, "", true);
   newdlg.set(params);
   newdlg.exec();
 }
@@ -491,7 +547,7 @@ void copyItem::sCopy()
     return;
   }
 
-  copyCopy.prepare("SELECT doUpdateCosts(:item_id, TRUE, :lowMaterial, :dirLabor, "
+  copyCopy.prepare("SELECT doUpdateCosts(:item_id, true, :lowMaterial, :dirLabor, "
                    "         :lowDirLabor, :overhead, :lowOverhead, :machOverhead, "
                    "         :lowMachOverhead, :lowUser, :rollUp, :updateActual)");
   copyCopy.bindValue(":item_id",         _newitemid);
@@ -532,7 +588,7 @@ void copyItem::sCopy()
     return;
   }
 
-  copyCopy.prepare( "SELECT doPostCosts(:item_id, TRUE, "
+  copyCopy.prepare( "SELECT doPostCosts(:item_id, true, "
                     "         :material, :lowMaterial, :labor, :lowLabor, "
                     "         :overhead, :lowOverhead, :machOverhead, :lowMachOverhead, "
                     "         :user, :lowUser, :rollUp)" );
@@ -578,10 +634,10 @@ void copyItem::sCopy()
   copyCopy.exec("COMMIT;");
   _inTransaction = false;
 
-  omfgThis->sItemsUpdated(_newitemid, TRUE);
+  omfgThis->sItemsUpdated(_newitemid, true);
 
   if (_copyBOM->isChecked())
-    omfgThis->sBOMsUpdated(_newitemid, TRUE);
+    omfgThis->sBOMsUpdated(_newitemid, true);
 
   if (_captive)
     done(_newitemid);
@@ -594,6 +650,8 @@ void copyItem::clear()
   _source->setId(-1);
   _targetItemNumber->clear();
   _targetItemDescrip->clear();
+  _listCost->clear();
+  _listPrice->clear();
   _availablebomitems->clear();
   _addedbomitems->clear();
   _addeditemsites->clear();
