@@ -22,7 +22,7 @@ class countSlip : public XDialog, public Ui::countSlip
     Q_OBJECT
 
 public:
-    countSlip(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    countSlip(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~countSlip();
 
 public slots:
