@@ -20,7 +20,7 @@ class createInvoices : public XDialog, public Ui::createInvoices
     Q_OBJECT
 
 public:
-    createInvoices(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    createInvoices(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~createInvoices();
 
 public slots:
