@@ -18,7 +18,7 @@
 #include <parameter.h>
 #include <openreports.h>
 
-createLotSerial::createLotSerial(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
+createLotSerial::createLotSerial(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
     : XDialog(parent, name, modal, fl),
       _lotsFound(false)
 {
@@ -28,7 +28,7 @@ createLotSerial::createLotSerial(QWidget* parent, const char* name, bool modal,
   connect(_lotSerial, SIGNAL(textChanged(QString)), this, SLOT(sHandleLotSerial()));
   connect(_lotSerial, SIGNAL(newID(int)), this, SLOT(sHandleCharacteristics()));
 
-  _item->setReadOnly(TRUE);
+  _item->setReadOnly(true);
 
   _serial = false;
   _itemsiteid = -1;
@@ -83,7 +83,7 @@ enum SetResponse createLotSerial::set(const ParameterList &pParams)
       {
         _serial = true;
         _qtyToAssign->setText("1");
-        _qtyToAssign->setEnabled(FALSE);
+        _qtyToAssign->setEnabled(false);
       }
       else
         _serial = false;
@@ -95,14 +95,18 @@ enum SetResponse createLotSerial::set(const ParameterList &pParams)
       _fractional = createet.value("item_fractional").toBool();
       
       //If there is preassigned trace info for an associated order, force user to select from list
+      //Pick latest lsdetail record as it can be duplicated when lot/serial returned/re-added to the shipment
       XSqlQuery preassign;
-      preassign.prepare("SELECT lsdetail_id,ls_number,ls_number "
+      preassign.prepare("SELECT MAX(lsdetail_id) AS lsdetail_id,ls_number,ls_number "
                         "FROM lsdetail JOIN ls ON (ls_id=lsdetail_ls_id) "
                         "WHERE ( (lsdetail_source_number=:docnumber) "
                         "AND (lsdetail_source_type=:transtype) "
-                        "AND (lsdetail_qtytoassign > 0) )");
+                        "AND (lsdetail_itemsite_id=:itemsite) "
+                        "AND (lsdetail_qtytoassign > 0) ) "
+                        "GROUP BY 2,3");
       preassign.bindValue(":transtype", createet.value("invhist_transtype").toString());
       preassign.bindValue(":docnumber", createet.value("invhist_ordnumber").toString());
+      preassign.bindValue(":itemsite", createet.value("itemsite_id").toInt());
       preassign.exec();
       if (preassign.first())
       {
@@ -177,6 +181,7 @@ void createLotSerial::sHandleCharacteristics()
 {
     if (_lotSerial->currentText().length() == 0)
     {
+        clearCharacteristics();
         return;
     }
 
@@ -199,11 +204,11 @@ void createLotSerial::sHandleCharacteristics()
     if (_lotsFound)
     {
         XSqlQuery charQuery;
-        charQuery.prepare(QString("SELECT char.char_type, charass.charass_value "
+        charQuery.prepare(QString("SELECT DISTINCT char.char_name, char.char_type, charass.charass_value "
                           " FROM charass INNER JOIN char ON charass.charass_char_id=char.char_id "
                           " WHERE charass.charass_target_type='LS' AND "
                           " charass.charass_target_id=%1 "
-                          " ORDER BY charass.charass_id ASC").arg(ls_id));
+                          " ORDER BY char.char_name ASC").arg(ls_id));
         success = charQuery.exec();
         if (!success)
         {
@@ -240,25 +245,7 @@ void createLotSerial::sHandleCharacteristics()
     }
     else
     {
-        QList<int> char_types = _lschars.getLotCharTypes();
-        for (int i=0; i < _lschars.numLotChars(); i++)
-        {
-            if (char_types.at(i) == 2)
-            {
-                DLineEdit *l = qobject_cast<DLineEdit *>(_charWidgets.at(i));
-                l->clear();
-            }
-            else if (char_types.at(i) == 1)
-            {
-                XComboBox *x = qobject_cast<XComboBox *>(_charWidgets.at(i));
-                x->setCurrentIndex(0);
-            }
-            else
-            {
-                QLineEdit *l = qobject_cast<QLineEdit *>(_charWidgets.at(i));
-                l->clear();
-            }
-        }
+      clearCharacteristics();
     }
     foreach (QWidget *w, _charWidgets)
     {
@@ -266,6 +253,29 @@ void createLotSerial::sHandleCharacteristics()
     }
 }
 
+void createLotSerial::clearCharacteristics()
+{
+  QList<int> char_types = _lschars.getLotCharTypes();
+  for (int i=0; i < _lschars.numLotChars(); i++)
+  {
+      if (char_types.at(i) == 2)
+      {
+          DLineEdit *l = qobject_cast<DLineEdit *>(_charWidgets.at(i));
+          l->clear();
+      }
+      else if (char_types.at(i) == 1)
+      {
+          XComboBox *x = qobject_cast<XComboBox *>(_charWidgets.at(i));
+          x->setCurrentIndex(0);
+      }
+      else
+      {
+          QLineEdit *l = qobject_cast<QLineEdit *>(_charWidgets.at(i));
+          l->clear();
+      }
+   }
+}
+
 void createLotSerial::sAssign()
 {
   XSqlQuery createAssign;
@@ -332,14 +342,19 @@ void createLotSerial::sAssign()
   
   if (_preassigned)
   {
-    createAssign.prepare("SELECT lsdetail_qtytoassign "
-              "FROM lsdetail "
-              "WHERE (lsdetail_id=:lsdetail_id);");
+    createAssign.prepare("SELECT SUM(lsd.lsdetail_qtytoassign) AS qtytoassign "
+              "FROM lsdetail lsd "
+              "JOIN lsdetail lsd2 "
+              "  ON (lsd.lsdetail_source_id=lsd2.lsdetail_source_id "
+              "    AND lsd.lsdetail_ls_id = lsd2.lsdetail_ls_id "
+              "    AND lsd.lsdetail_source_type = lsd2.lsdetail_source_type "
+              "    AND lsd.lsdetail_source_number = lsd2.lsdetail_source_number) "
+              " WHERE (lsd2.lsdetail_id=:lsdetail_id);");
     createAssign.bindValue(":lsdetail_id", _lotSerial->id());
     createAssign.exec();
     if (createAssign.first())
     {
-      if ( _qtyToAssign->toDouble() > createAssign.value("lsdetail_qtytoassign").toDouble() )
+      if ( _qtyToAssign->toDouble() > createAssign.value("qtytoassign").toDouble() )
       {
         QMessageBox::critical( this, tr("Invalid Qty"),
                                tr( "<p>The quantity being assigned is greater than the "
@@ -480,6 +495,13 @@ void createLotSerial::sLotSerialSelected()
         !_warranty->isEnabled())
       return;
 
+    if (_lotSerial->currentText().length() == 0)
+    {
+        _expiration->clear();
+        _warranty->clear();
+        return;
+    }
+
     XSqlQuery itemloc;
     itemloc.prepare("SELECT itemloc_expiration, itemloc_warrpurc "
                     "FROM itemloc "
@@ -487,7 +509,11 @@ void createLotSerial::sLotSerialSelected()
                     "UNION "
                     "SELECT itemloc_expiration, itemloc_warrpurc "
                     "FROM lsdetail JOIN itemloc ON (itemloc_itemsite_id=lsdetail_itemsite_id AND itemloc_ls_id=lsdetail_ls_id) "
-                    "WHERE lsdetail_id=:itemloc_id;");
+                    "WHERE lsdetail_id=:itemloc_id "
+                    "UNION "
+                    "SELECT lsdetail_expiration, lsdetail_warrpurc "
+                    "FROM lsdetail "
+                    "WHERE lsdetail_id=:itemloc_id; ");
     itemloc.bindValue(":itemloc_id", _lotSerial->id());
     itemloc.exec();
     if (itemloc.first()) {
