@@ -22,7 +22,7 @@ class currencySelect : public XDialog, public Ui::currencySelect
     Q_OBJECT
 
 public:
-    currencySelect(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    currencySelect(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~currencySelect();
 
 public slots:
