@@ -13,8 +13,11 @@
 
 #include "guiclient.h"
 #include "xwidget.h"
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui/QWidget>
-
+#endif
 #include "ui_departments.h"
 
 class departments : public XWidget, public Ui::departments
@@ -22,7 +25,7 @@ class departments : public XWidget, public Ui::departments
     Q_OBJECT
 
 public:
-    departments(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    departments(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~departments();
 
 public slots:
