@@ -22,7 +22,7 @@ class dspAPOpenItemsByVendor : public display, public Ui::dspAPOpenItemsByVendor
     Q_OBJECT
 
 public:
-    dspAPOpenItemsByVendor(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspAPOpenItemsByVendor(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList&);
     virtual bool checkSitePrivs(int orderid);
