@@ -19,7 +19,7 @@ class dspBacklog : public display
     Q_OBJECT
 
 public:
-    dspBacklog(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspBacklog(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
 public slots:
     virtual SetResponse set(const ParameterList & pParams );
