@@ -18,7 +18,7 @@ class dspCapacityUOMsByClassCode : public dspCapacityUOMsByParameter
     Q_OBJECT
 
 public:
-    dspCapacityUOMsByClassCode(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspCapacityUOMsByClassCode(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
