@@ -18,7 +18,7 @@ class dspCostedSingleLevelBOM : public dspCostedBOMBase
     Q_OBJECT
 
 public:
-    dspCostedSingleLevelBOM(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspCostedSingleLevelBOM(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &params);
 
