@@ -21,7 +21,7 @@ class dspCostedSummarizedBOM : public display, public Ui::dspCostedSummarizedBOM
     Q_OBJECT
 
 public:
-    dspCostedSummarizedBOM(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspCostedSummarizedBOM(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &params);
 
