@@ -21,7 +21,7 @@ class dspGLSeries : public display, public Ui::dspGLSeries
     Q_OBJECT
 
 public:
-    dspGLSeries(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspGLSeries(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
