@@ -19,7 +19,7 @@ class dspJournals : public display
     Q_OBJECT
 
 public:
-    dspJournals(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspJournals(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &params);
 
