@@ -20,7 +20,7 @@ class dspPoItemsByDate : public display, public Ui::dspPoItemsByDate
     Q_OBJECT
 
 public:
-    dspPoItemsByDate(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspPoItemsByDate(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &params);
 
