@@ -20,7 +20,7 @@ class dspPricesByCustomerType : public display, public Ui::dspPricesByCustomerTy
     Q_OBJECT
 
 public:
-    dspPricesByCustomerType(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspPricesByCustomerType(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
