@@ -22,7 +22,7 @@ class dspQuotesByCustomer : public display, public Ui::dspQuotesByCustomer
     Q_OBJECT
 
 public:
-    dspQuotesByCustomer(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspQuotesByCustomer(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool checkSitePrivs(int orderid);
     virtual bool setParams(ParameterList&);
