@@ -18,7 +18,7 @@ class dspSingleLevelBOM : public dspBOMBase
     Q_OBJECT
 
 public:
-    dspSingleLevelBOM(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspSingleLevelBOM(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &params);
 
