@@ -23,7 +23,7 @@ class dspSubstituteAvailabilityByItem : public display, public Ui::dspSubstitute
     Q_OBJECT
 
 public:
-    dspSubstituteAvailabilityByItem(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspSubstituteAvailabilityByItem(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParams(ParameterList &);
 
