@@ -20,7 +20,7 @@ class dspTimePhasedBookings : public displayTimePhased, public Ui::dspTimePhased
     Q_OBJECT
 
 public:
-    dspTimePhasedBookings(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    dspTimePhasedBookings(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
     virtual bool setParamsTP(ParameterList &);
 
