@@ -22,7 +22,7 @@ class enterMiscCount : public XDialog, public Ui::enterMiscCount
     Q_OBJECT
 
 public:
-    enterMiscCount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    enterMiscCount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~enterMiscCount();
 
 public slots:
