@@ -22,7 +22,7 @@ class expenseTrans : public XWidget, public Ui::expenseTrans
     Q_OBJECT
 
 public:
-    expenseTrans(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    expenseTrans(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~expenseTrans();
 
     Q_INVOKABLE int projectId() { return _prjid; }
