@@ -10,7 +10,7 @@
 
 #include "getGLDistDate.h"
 
-getGLDistDate::getGLDistDate(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
+getGLDistDate::getGLDistDate(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
     : XDialog(parent, name, modal, fl)
 {
   setupUi(this);
