@@ -22,7 +22,7 @@ class getLotInfo : public XDialog, public Ui::getLotInfo
     Q_OBJECT
 
 public:
-    getLotInfo(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    getLotInfo(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~getLotInfo();
 
 public slots:
