@@ -232,10 +232,8 @@ CLASSITEM(dspReorderExceptionsByPlannerCode)
 CLASSITEM(dspReservations)
 CLASSITEM(dspRunningAvailability)
 CLASSITEM(dspSalesHistory)
-CLASSITEM(dspSalesOrdersByCustomer)
-CLASSITEM(dspSalesOrdersByCustomerPO)
+CLASSITEM(dspSalesOrders)
 CLASSITEM(dspSalesOrdersByItem)
-CLASSITEM(dspSalesOrdersByParameterList)
 CLASSITEM(dspSalesOrderStatus)
 CLASSITEM(dspShipmentsByDate)
 CLASSITEM(dspShipmentsBySalesOrder)
