@@ -232,10 +232,8 @@
 #include "dspReservations.h"
 #include "dspRunningAvailability.h"
 #include "dspSalesHistory.h"
-#include "dspSalesOrdersByCustomer.h"
-#include "dspSalesOrdersByCustomerPO.h"
+#include "dspSalesOrders.h"
 #include "dspSalesOrdersByItem.h"
-#include "dspSalesOrdersByParameterList.h"
 #include "dspSalesOrderStatus.h"
 #include "dspShipmentsByDate.h"
 #include "dspShipmentsBySalesOrder.h"
