@@ -17,13 +17,14 @@
 #include <QVariant>
 
 #include "arOpenItem.h"
+#include "errorReporter.h"
 #include "returnAuthorization.h"
 #include "storedProcErrorLookup.h"
 #include "todoItem.h"
-#include "characteristicAssignment.h"
+
 #include <openreports.h>
 
-incident::incident(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
+incident::incident(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
     : XDialog(parent, name, modal, fl)
 {
   _statusCodes << "N" << "F" << "C" << "A" << "R" << "L";
@@ -46,7 +47,6 @@ incident::incident(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
   connect(_editTodoItem,  SIGNAL(clicked()),        this,       SLOT(sEditTodoItem()));
   connect(_item,          SIGNAL(newId(int)),     _lotserial,   SLOT(setItemId(int)));
   connect(_newTodoItem,   SIGNAL(clicked()),        this,       SLOT(sNewTodoItem()));
-  //connect(_return,      SIGNAL(clicked()),        this, SLOT(sReturn()));
   connect(_buttonBox,     SIGNAL(accepted()),        this,       SLOT(sSave()));
   connect(_print,         SIGNAL(clicked()),        this,       SLOT(sPrint()));
   connect(_todoList,      SIGNAL(itemSelected(int)), _editTodoItem, SLOT(animateClick()));
@@ -54,22 +54,14 @@ incident::incident(QWidget* parent, const char* name, bool modal, Qt::WFlags fl)
   connect(_todoList,      SIGNAL(valid(bool)),      this, SLOT(sHandleTodoPrivs()));
   connect(_viewAR,        SIGNAL(clicked()),        this, SLOT(sViewAR()));
   connect(_viewTodoItem,  SIGNAL(clicked()),        this,       SLOT(sViewTodoItem()));
-  connect(_deleteCharacteristic,SIGNAL(clicked()), this, SLOT(sDeleteCharacteristic()));
-  connect(_editCharacteristic,	SIGNAL(clicked()), this, SLOT(sEditCharacteristic()));
-  connect(_newCharacteristic,	SIGNAL(clicked()), this, SLOT(sNewCharacteristic()));
-  connect(_charass, SIGNAL(valid(bool)), _editCharacteristic, SLOT(setEnabled(bool)));
-  connect(_charass, SIGNAL(valid(bool)), _deleteCharacteristic, SLOT(setEnabled(bool)));
-  connect(_charass, SIGNAL(itemSelected(int)), _editCharacteristic, SLOT(animateClick()));
 
+  _charass->setType("INCDT");
   _severity->setType(XComboBox::IncidentSeverity);
   _priority->setType(XComboBox::IncidentPriority);
   _resolution->setType(XComboBox::IncidentResolution);
   _category->setType(XComboBox::IncidentCategory);
   _lotserial->setStrict(false);
 
-  _charass->addColumn(tr("Characteristic"), _itemColumn, Qt::AlignLeft, true, "char_name");
-  _charass->addColumn(tr("Value"),          -1,          Qt::AlignLeft, true, "charass_value");
-
   _incdthist->addColumn(tr("Username"),     _userColumn, Qt::AlignLeft, true, "incdthist_username");
   _incdthist->addColumn(tr("Date/Time"),_timeDateColumn, Qt::AlignLeft, true, "incdthist_timestamp");
   _incdthist->addColumn(tr("Description"),           -1, Qt::AlignLeft, true, "incdthist_descrip");
@@ -125,6 +117,7 @@ enum SetResponse incident::set(const ParameterList &pParams)
     _incdtid = param.toInt();
     populate();
     _lotserial->setItemId(_item->id());
+    _charass->setId(_incdtid);
   }
 
   param = pParams.value("mode", &valid);
@@ -142,6 +135,7 @@ enum SetResponse incident::set(const ParameterList &pParams)
         _number->setText(incidentet.value("number").toString());
         _comments->setId(_incdtid);
         _documents->setId(_incdtid);
+        _charass->setId(_incdtid);
         _alarms->setId(_incdtid);
         _recurring->setParent(_incdtid, "INCDT");
         _print->hide();
@@ -179,10 +173,7 @@ enum SetResponse incident::set(const ParameterList &pParams)
       _deleteTodoItem->setEnabled(false);
       _editTodoItem->setEnabled(false);
       _newTodoItem->setEnabled(false);
-      disconnect(_charass, SIGNAL(valid(bool)), _editCharacteristic, SLOT(setEnabled(bool)));
-      disconnect(_charass, SIGNAL(valid(bool)), _deleteCharacteristic, SLOT(setEnabled(bool)));
-      disconnect(_charass, SIGNAL(itemSelected(int)), _editCharacteristic, SLOT(animateClick()));
-      _newCharacteristic->setEnabled(false);
+      _charass->setReadOnly(true);
       _owner->setEnabled(false);
 
       _buttonBox->setStandardButtons(QDialogButtonBox::Close);
@@ -557,6 +548,7 @@ void incident::populate()
 
     _comments->setId(_incdtid);
     _documents->setId(_incdtid);
+    _charass->setId(_incdtid);
     _alarms->setId(_incdtid);
 
     _project->setId(incidentpopulate.value("incdt_prj_id").toInt());
@@ -573,7 +565,6 @@ void incident::populate()
                           _incdtid : incidentpopulate.value("incdt_recurring_incdt_id").toInt(),
                           "INCDT");
 
-    sFillCharacteristicsList();
     sFillHistoryList();
     sFillTodoList();
 
@@ -652,25 +643,28 @@ void incident::sDeleteTodoItem()
 void incident::sFillTodoList()
 {
   XSqlQuery incidentFillTodoList;
-  incidentFillTodoList.prepare("SELECT todoitem_id, *, "
-            "       firstLine(todoitem_notes) AS todoitem_notes, "
+  incidentFillTodoList.prepare("SELECT todoitem_id, todoitem_owner_username,"
+            "       firstLine(todoitem_notes) AS todoitem_notes,"
+            "       todoitem_username, todoitem_name, todoitem_description,"
+            "       todoitem_status, todoitem_due_date,"
+            "       incdtpriority_name,"
             "       CASE WHEN (todoitem_status != 'C' AND"
             "                  todoitem_due_date < CURRENT_DATE) THEN 'expired'"
             "            WHEN (todoitem_status != 'C' AND"
             "                  todoitem_due_date > CURRENT_DATE) THEN 'future'"
             "       END AS todoitem_due_date_qtforegroundrole "
             "  FROM todoitem "
-            "       LEFT OUTER JOIN incdtpriority ON (incdtpriority_id=todoitem_priority_id) "
-            "WHERE ( (todoitem_incdt_id=:incdt_id) "
-            "  AND   (todoitem_active) ) "
-            "ORDER BY todoitem_due_date, todoitem_username;");
+            "  LEFT OUTER JOIN incdtpriority ON (incdtpriority_id=todoitem_priority_id)"
+            " WHERE ((todoitem_incdt_id=:incdt_id)"
+            "   AND  todoitem_active )"
+            " ORDER BY todoitem_due_date, todoitem_username;");
 
   incidentFillTodoList.bindValue(":incdt_id", _incdtid);
   incidentFillTodoList.exec();
   _todoList->populate(incidentFillTodoList);
-  if (incidentFillTodoList.lastError().type() != QSqlError::NoError)
+  if (ErrorReporter::error(QtCriticalMsg, this, tr("Getting To-Do Items"),
+                           incidentFillTodoList, __FILE__, __LINE__))
   {
-    systemError(this, incidentFillTodoList.lastError().databaseText(), __FILE__, __LINE__);
     return;
   }
 }
@@ -811,62 +805,3 @@ void incident::sAssigned()
   if (_status->currentIndex() < 3 && !_assignedTo->username().isEmpty())
     _status->setCurrentIndex(3);
 }
-
-void incident::sNewCharacteristic()
-{
-  if (! save(true))
-    return;
-
-  ParameterList params;
-  params.append("mode", "new");
-  params.append("incdt_id", _incdtid);
-
-  characteristicAssignment newdlg(this, "", TRUE);
-  newdlg.set(params);
-
-  if (newdlg.exec() != XDialog::Rejected)
-    sFillCharacteristicsList();
-}
-
-void incident::sEditCharacteristic()
-{
-  ParameterList params;
-  params.append("mode", "edit");
-  params.append("charass_id", _charass->id());
-
-  characteristicAssignment newdlg(this, "", TRUE);
-  newdlg.set(params);
-
-  if (newdlg.exec() != XDialog::Rejected)
-    sFillCharacteristicsList();
-}
-
-void incident::sDeleteCharacteristic()
-{
-  XSqlQuery incidentDeleteCharacteristic;
-  incidentDeleteCharacteristic.prepare( "DELETE FROM charass "
-             "WHERE (charass_id=:charass_id);" );
-  incidentDeleteCharacteristic.bindValue(":charass_id", _charass->id());
-  incidentDeleteCharacteristic.exec();
-
-  sFillCharacteristicsList();
-}
-
-void incident::sFillCharacteristicsList()
-{
-  XSqlQuery qry;
-  qry.prepare( "SELECT charass_id, char_name, "
-               " CASE WHEN char_type < 2 THEN "
-               "   charass_value "
-               " ELSE "
-               "   formatDate(charass_value::date) "
-               "END AS charass_value "
-               "FROM charass, char "
-               "WHERE ( (charass_target_type='INCDT')"
-               " AND (charass_char_id=char_id)"
-               " AND (charass_target_id=:incdt_id) ) "
-               "ORDER BY char_order, char_name;" );
-  qry.bindValue(":incdt_id", _incdtid);
-  qry.exec();
-  _charass->populate(qry);
-}
