@@ -21,7 +21,7 @@ class incidentResolutions : public XWidget, public Ui::incidentResolutions
     Q_OBJECT
 
 public:
-    incidentResolutions(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    incidentResolutions(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~incidentResolutions();
 
 public slots:
