@@ -14,7 +14,11 @@
 #define LOTSERIALUTILS_H
 
 #include <QtCore>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#else
 #include <QtGui>
+#endif
 #include "parameter.h"
 
 class LotSerialUtils
