@@ -16,12 +16,11 @@
 #include <QSqlError>
 #include <QVariant>
 
-#include "characteristicAssignment.h"
 #include "guiErrorCheck.h"
 #include "errorReporter.h"
 #include "voucherMiscDistrib.h"
 
-miscVoucher::miscVoucher(QWidget* parent, const char* name, Qt::WFlags fl)
+miscVoucher::miscVoucher(QWidget* parent, const char* name, Qt::WindowFlags fl)
     : XWidget(parent, name, fl)
 {
   setupUi(this);
@@ -39,22 +38,20 @@ miscVoucher::miscVoucher(QWidget* parent, const char* name, Qt::WFlags fl)
   connect(_new,                  SIGNAL(clicked()),                      this, SLOT(sNewMiscDistribution()));
   connect(_save,                 SIGNAL(clicked()),                      this, SLOT(sSave()));
   connect(_voucherNumber,        SIGNAL(editingFinished()),              this, SLOT(sHandleVoucherNumber()));
-  connect(_newCharacteristic,    SIGNAL(clicked()),                      this, SLOT(sNewCharacteristic()));
-  connect(_editCharacteristic,   SIGNAL(clicked()),                      this, SLOT(sEditCharacteristic()));
-  connect(_deleteCharacteristic, SIGNAL(clicked()),                      this, SLOT(sDeleteCharacteristic()));
 
   _terms->setType(XComboBox::APTerms);
 
   _vendor->setShowInactive(false);
 
+  _postVoucher->setEnabled(_privileges->check("PostVouchers"));
+
   _recurring->setParent(-1, "V");
 
   _miscDistrib->addColumn(tr("Account"),    -1,           Qt::AlignLeft,   true,  "account"  );
   _miscDistrib->addColumn(tr("Amount"),     _moneyColumn, Qt::AlignRight,  true,  "vodist_amount" );
   _miscDistrib->addColumn(tr("Notes"),      -1,           Qt::AlignLeft,   true,  "vodist_notes"  );
 
-  _charass->addColumn(tr("Characteristic"), _itemColumn,  Qt::AlignLeft,   true,  "char_name" );
-  _charass->addColumn(tr("Value"),          -1,           Qt::AlignLeft,   true,  "charass_value" );
+  _charass->setType("VCH");
 }
 
 miscVoucher::~miscVoucher()
@@ -101,8 +98,7 @@ enum SetResponse miscVoucher::set(const ParameterList &pParams)
         _voheadid = insq.value("vohead_id").toInt();
         _recurring->setParent(_voheadid, "V");
         _documents->setId(_voheadid);
-        connect(_charass, SIGNAL(valid(bool)), _editCharacteristic, SLOT(setEnabled(bool)));
-        connect(_charass, SIGNAL(valid(bool)), _deleteCharacteristic, SLOT(setEnabled(bool)));
+        _charass->setId(_voheadid);
       }
       else if (ErrorReporter::error(QtCriticalMsg, this, tr("Creating Voucher"),
                                insq, __FILE__, __LINE__))
@@ -114,8 +110,6 @@ enum SetResponse miscVoucher::set(const ParameterList &pParams)
 
       _voucherNumber->setEnabled(false);
       _vendor->setEnabled(false);
-      connect(_charass, SIGNAL(valid(bool)), _editCharacteristic, SLOT(setEnabled(bool)));
-      connect(_charass, SIGNAL(valid(bool)), _deleteCharacteristic, SLOT(setEnabled(bool)));
     }
     else if (param.toString() == "view")
     {
@@ -138,9 +132,10 @@ enum SetResponse miscVoucher::set(const ParameterList &pParams)
       _flagFor1099->setEnabled(false);
       _notes->setEnabled(false);
 //    _documents->setReadOnly(true);
-      _newCharacteristic->setEnabled(FALSE);
+      _charass->setReadOnly(true);
       _close->setText(tr("&Close"));
       _save->hide();
+      _postVoucher->setVisible(false);
 
     }
   }
@@ -154,6 +149,7 @@ enum SetResponse miscVoucher::set(const ParameterList &pParams)
   {
     _voheadid = param.toInt();
     _documents->setId(_voheadid);
+    _charass->setId(_voheadid);
     populate();
   }
 
@@ -297,6 +293,9 @@ void miscVoucher::sSave()
 
   XSqlQuery commitq("COMMIT;");
 
+  if (_postVoucher->isChecked())
+    postVoucher();
+
   omfgThis->sVouchersUpdated();
 
   _voheadid = -1;
@@ -325,6 +324,36 @@ void miscVoucher::sSave()
   ParameterList params;
   params.append("mode", "new");
   set(params);
+  _vendor->setFocus();
+
+}
+
+void miscVoucher::postVoucher()
+{
+  XSqlQuery post;
+  post.prepare("SELECT fetchJournalNumber('AP-VO') AS result;");
+  post.exec();
+  int journalNumber = 0;
+  if(post.first())
+    journalNumber = post.value("result").toInt();
+  else if (ErrorReporter::error(QtCriticalMsg, this, tr("Getting Journal Number"),
+                                post, __FILE__, __LINE__))
+    return;
+
+  post.prepare("SELECT postVoucher(:vohead_id, :journalNumber, FALSE) AS result;");
+  post.bindValue(":vohead_id", _voheadid);
+  post.bindValue(":journalNumber", journalNumber);
+  post.exec();
+  if (post.first())
+  {
+    int result = post.value("result").toInt();
+    if (result < 0)
+      ErrorReporter::error(QtCriticalMsg, this, tr("Posting Voucher"),
+                         post, __FILE__, __LINE__);
+  }
+  else
+    ErrorReporter::error(QtCriticalMsg, this, tr("Posting Voucher"),
+                         post, __FILE__, __LINE__);
 }
 
 void miscVoucher::sHandleVoucherNumber()
@@ -391,62 +420,6 @@ void miscVoucher::sPopulateVendorInfo(int pVendid)
     return;
 }
 
-void miscVoucher::sNewCharacteristic()
-{
-  ParameterList params;
-  params.append("mode", "new");
-  params.append("vohead_id", _voheadid);
-  
-  characteristicAssignment newdlg(this, "", TRUE);
-  newdlg.set(params);
-  
-  if (newdlg.exec() != XDialog::Rejected)
-    sFillCharacteristic();
-}
-
-void miscVoucher::sEditCharacteristic()
-{
-  ParameterList params;
-  params.append("mode", "edit");
-  params.append("charass_id", _charass->id());
-  
-  characteristicAssignment newdlg(this, "", TRUE);
-  newdlg.set(params);
-  
-  if (newdlg.exec() != XDialog::Rejected)
-    sFillCharacteristic();
-}
-
-void miscVoucher::sDeleteCharacteristic()
-{
-  XSqlQuery itemDelete;
-  itemDelete.prepare( "DELETE FROM charass "
-                     "WHERE (charass_id=:charass_id);" );
-  itemDelete.bindValue(":charass_id", _charass->id());
-  itemDelete.exec();
-  
-  sFillCharacteristic();
-}
-
-void miscVoucher::sFillCharacteristic()
-{
-  XSqlQuery charassq;
-  charassq.prepare( "SELECT charass_id, char_name, "
-                   " CASE WHEN char_type < 2 THEN "
-                   "   charass_value "
-                   " ELSE "
-                   "   formatDate(charass_value::date) "
-                   "END AS charass_value "
-                   "FROM charass JOIN char ON (char_id=charass_char_id) "
-                   "WHERE ( (charass_target_type=:target_type)"
-                   "  AND   (charass_target_id=:target_id) ) "
-                   "ORDER BY char_order, char_name;" );
-  charassq.bindValue(":target_id", _voheadid);
-  charassq.bindValue(":target_type", "VCH");
-  charassq.exec();
-  _charass->populate(charassq);
-}
-
 void miscVoucher::sNewMiscDistribution()
 {
   ParameterList params;
@@ -460,7 +433,7 @@ void miscVoucher::sNewMiscDistribution()
   if (_taxzone->isValid())
    params.append("taxzone_id", _taxzone->id());
 
-  voucherMiscDistrib newdlg(this, "", TRUE);
+  voucherMiscDistrib newdlg(this, "", true);
   newdlg.set(params);
   if (newdlg.exec() != XDialog::Rejected)
   {
@@ -481,7 +454,7 @@ void miscVoucher::sEditMiscDistribution()
   if (_taxzone->isValid())
    params.append("taxzone_id", _taxzone->id());
 
-  voucherMiscDistrib newdlg(this, "", TRUE);
+  voucherMiscDistrib newdlg(this, "", true);
   newdlg.set(params);
   if (newdlg.exec() != XDialog::Rejected)
   {
@@ -574,7 +547,7 @@ void miscVoucher::populateNumber()
   if (numq.first())
   {
     _voucherNumber->setText(numq.value("vouchernumber").toString());
-    _voucherNumber->setEnabled(FALSE);
+    _voucherNumber->setEnabled(false);
   }
   else if (ErrorReporter::error(QtCriticalMsg, this, tr("Getting Number"),
                                 numq, __FILE__, __LINE__))
@@ -612,10 +585,11 @@ void miscVoucher::populate()
     else
       _recurring->setParent(_voheadid, "V");
 
+    if(vohead.value("vohead_posted").toBool())
+      _postVoucher->setVisible(false);
 
     sFillMiscList();
     sPopulateDistributed();
-    sFillCharacteristic();
   }
   else if (ErrorReporter::error(QtCriticalMsg, this, tr("Getting Voucher"),
                                 vohead, __FILE__, __LINE__))
