@@ -22,7 +22,7 @@ class openReturnAuthorizations : public XWidget, public Ui::openReturnAuthorizat
     Q_OBJECT
 
 public:
-    openReturnAuthorizations(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    openReturnAuthorizations(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~openReturnAuthorizations();
     
     virtual void setParams(ParameterList &);
