@@ -21,7 +21,7 @@ class packages : public XWidget, public Ui::packages
     Q_OBJECT
 
 public:
-    packages(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    packages(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~packages();
 
 public slots:
