@@ -21,7 +21,7 @@ class poLiabilityDistrib : public XDialog, public Ui::poLiabilityDistrib
     Q_OBJECT
 
 public:
-    poLiabilityDistrib(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    poLiabilityDistrib(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~poLiabilityDistrib();
 
 public slots:
