@@ -20,7 +20,7 @@ class postInvoices : public XDialog, public Ui::postInvoices
     Q_OBJECT
 
 public:
-    postInvoices(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    postInvoices(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~postInvoices();
 
 public slots:
