@@ -21,7 +21,7 @@ class postPoReturnCreditMemo : public XDialog, public Ui::postPoReturnCreditMemo
     Q_OBJECT
 
 public:
-    postPoReturnCreditMemo(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    postPoReturnCreditMemo(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~postPoReturnCreditMemo();
 
 public slots:
