@@ -29,7 +29,7 @@
 
 QString printCheck::eftFileDir = QString();
 
-printCheck::printCheck(QWidget* parent, const char* name, Qt::WFlags fl)
+printCheck::printCheck(QWidget* parent, const char* name, Qt::WindowFlags fl)
     : XWidget(parent, name, fl)
 {
   setupUi(this);
@@ -38,13 +38,15 @@ printCheck::printCheck(QWidget* parent, const char* name, Qt::WFlags fl)
   connect(_check,     SIGNAL(newID(int)), this, SLOT(sEnableCreateEFT()));
   connect(_createEFT, SIGNAL(clicked()),  this, SLOT(sCreateEFT()));
   connect(_print,     SIGNAL(clicked()),  this, SLOT(sPrint()));
+  connect(_printed,   SIGNAL(clicked()),  this, SLOT(sPrintedAlready()));
 
-  _captive = FALSE;
+  _captive = false;
   _setCheckNumber = -1;
 
-  _check->setAllowNull(TRUE);
+  _check->setAllowNull(true);
 
   _bankaccnt->setType(XComboBox::APBankAccounts);
+  sHandleBankAccount(_bankaccnt->id());
 
   _createEFT->setVisible(_metrics->boolean("ACHSupported") && _metrics->boolean("ACHEnabled"));
 }
@@ -62,7 +64,7 @@ void printCheck::languageChange()
 enum SetResponse printCheck::set(const ParameterList &pParams)
 {
   XWidget::set(pParams);
-  _captive = TRUE;
+  _captive = true;
 
   QVariant param;
   bool     valid;
@@ -71,14 +73,24 @@ enum SetResponse printCheck::set(const ParameterList &pParams)
   if (valid)
   {
     populate(param.toInt());
-    _bankaccnt->setEnabled(FALSE);
-    _check->setEnabled(FALSE);
+    _bankaccnt->setEnabled(false);
+    _check->setEnabled(false);
   }
 
   return NoError;
 }
 
 void printCheck::sPrint()
+{
+  sPrintImpl(false);
+}
+
+void printCheck::sPrintedAlready()
+{
+  sPrintImpl(true);
+}
+
+void printCheck::sPrintImpl(bool printedAlready)
 {
   XSqlQuery printPrint;
   if(_setCheckNumber != -1 && _setCheckNumber != _nextCheckNum->text().toInt())
@@ -106,6 +118,7 @@ void printCheck::sPrint()
   }
 
   if (_createEFT->isEnabled() &&
+      !printedAlready &&
       QMessageBox::question(this, tr("Print Anyway?"),
                             tr("<p>The recipient of this check has been "
                                "configured for EFT transactions. Do you want "
@@ -196,6 +209,12 @@ void printCheck::sPrint()
       return;
     }
 
+    if(printedAlready)
+    {
+      markCheckAsPrinted(_check->id());
+      return;
+    }
+
     ParameterList params;
 
     params.append("checkhead_id", _check->id());
@@ -234,12 +253,12 @@ void printCheck::sPrint()
                  "       checkhead_for, checkhead_notes,"
                  "       checkhead_curr_id, checkhead_deleted) "
                  "SELECT checkhead_recip_id, checkhead_recip_type,"
-                 "       checkhead_bankaccnt_id, TRUE,"
+                 "       checkhead_bankaccnt_id, true,"
                  "       checkhead_checkdate, fetchNextCheckNumber(checkhead_bankaccnt_id),"
-                 "       checkhead_amount, TRUE, TRUE,"
+                 "       checkhead_amount, true, true,"
                  "       'Continuation of Check #'||checkhead_number,"
                  "       'Continuation of Check #'||checkhead_number,"
-                 "       checkhead_curr_id, TRUE"
+                 "       checkhead_curr_id, true"
                  "  FROM checkhead"
                  " WHERE(checkhead_id=:checkhead_id);");
       qq.bindValue(":checkhead_id", _check->id());
@@ -249,7 +268,7 @@ void printCheck::sPrint()
       }
     }
 
-    omfgThis->sChecksUpdated(_bankaccnt->id(), _check->id(), TRUE);
+    omfgThis->sChecksUpdated(_bankaccnt->id(), _check->id(), true);
   }
   else if (printPrint.lastError().type() != QSqlError::NoError)
   {
@@ -314,7 +333,7 @@ void printCheck::sPrint()
 	return;
       }
       omfgThis->sChecksUpdated(printPrint.value("checkhead_bankaccnt_id").toInt(),
-			       _check->id(), TRUE);
+			       _check->id(), true);
 
       sHandleBankAccount(_bankaccnt->id());
       _print->setFocus();
@@ -449,7 +468,7 @@ void printCheck::sCreateEFT()
     }
     do
     {
-      eftfile.write(printCreateEFT.value("achline_value").toString().toAscii());
+      eftfile.write(printCreateEFT.value("achline_value").toString().toLatin1());
       eftfile.write("\n");
     } while (printCreateEFT.next());
     eftfile.close();
@@ -552,7 +571,7 @@ void printCheck::markCheckAsPrinted(const int pcheckid)
       return;
     }
     omfgThis->sChecksUpdated(markq.value("checkhead_bankaccnt_id").toInt(),
-                             pcheckid, TRUE);
+                             pcheckid, true);
 
     if (_captive)
       close();
