@@ -20,7 +20,7 @@ class printCreditMemo : public printMulticopyDocument,
     Q_OBJECT
 
   public:
-    printCreditMemo(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    printCreditMemo(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~printCreditMemo();
 
   protected slots:
