@@ -21,7 +21,7 @@ class printItemLabelsByClassCode : public XDialog, public Ui::printItemLabelsByC
     Q_OBJECT
 
 public:
-    printItemLabelsByClassCode(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    printItemLabelsByClassCode(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~printItemLabelsByClassCode();
 
 public slots:
