@@ -19,7 +19,7 @@ class printPurchaseOrdersByAgent : public XDialog, public Ui::printPurchaseOrder
     Q_OBJECT
 
   public:
-    printPurchaseOrdersByAgent(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    printPurchaseOrdersByAgent(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~printPurchaseOrdersByAgent();
 
   public slots:
