@@ -19,7 +19,7 @@ class printVendorForm : public XDialog, public Ui::printVendorForm
     Q_OBJECT
 
 public:
-    printVendorForm(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    printVendorForm(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~printVendorForm();
 
 public slots:
