@@ -21,7 +21,7 @@ class profitCenter : public XDialog, public Ui::profitCenter
     Q_OBJECT
 
 public:
-    profitCenter(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    profitCenter(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~profitCenter();
 
 public slots:
