@@ -19,7 +19,7 @@ class prospects : public display
     Q_OBJECT
 
 public:
-    prospects(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    prospects(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
 
 public slots:
     virtual void sDelete();
