@@ -20,7 +20,7 @@ class reassignCustomerTypeByCustomerType : public XDialog, public Ui::reassignCu
     Q_OBJECT
 
 public:
-    reassignCustomerTypeByCustomerType(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    reassignCustomerTypeByCustomerType(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~reassignCustomerTypeByCustomerType();
 
 public slots:
