@@ -21,7 +21,7 @@ class reassignLotSerial : public XDialog, public Ui::reassignLotSerial
     Q_OBJECT
 
 public:
-    reassignLotSerial(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    reassignLotSerial(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~reassignLotSerial();
 
 public slots:
