@@ -20,7 +20,7 @@ class registrationKeyDialog : public QDialog, public Ui::registrationKeyDialog
     Q_OBJECT
 
 public:
-    registrationKeyDialog(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    registrationKeyDialog(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~registrationKeyDialog();
 
 public slots:
