@@ -21,7 +21,7 @@ class relativeCalendarItem : public XDialog, public Ui::relativeCalendarItem
     Q_OBJECT
 
 public:
-    relativeCalendarItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    relativeCalendarItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~relativeCalendarItem();
 
 public slots:
