@@ -21,7 +21,7 @@ class reprintCreditMemos : public reprintMulticopyDocument,
 
   public:
     reprintCreditMemos(QWidget *parent = 0,     const char *name = 0,
-                       bool     modal  = false, Qt::WFlags  fl   = 0);
+                       bool     modal  = false, Qt::WindowFlags  fl   = 0);
     ~reprintCreditMemos();
 
   protected slots:
