@@ -21,7 +21,7 @@ class salesAccount : public XDialog, public Ui::salesAccount
     Q_OBJECT
 
 public:
-    salesAccount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    salesAccount(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~salesAccount();
 
 public slots:
