@@ -21,7 +21,7 @@ class salesOrderInformation : public XDialog, public Ui::salesOrderInformation
     Q_OBJECT
 
 public:
-    salesOrderInformation(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    salesOrderInformation(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~salesOrderInformation();
 
 public slots:
