@@ -21,7 +21,7 @@ class scrapWoMaterialFromWIP : public XDialog, public Ui::scrapWoMaterialFromWIP
     Q_OBJECT
 
 public:
-    scrapWoMaterialFromWIP(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    scrapWoMaterialFromWIP(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~scrapWoMaterialFromWIP();
 
 public slots:
