@@ -22,7 +22,7 @@ class splitReceipt : public XDialog, public Ui::splitReceipt
     Q_OBJECT
 
 public:
-    splitReceipt(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    splitReceipt(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~splitReceipt();
 
 public slots:
