@@ -25,10 +25,11 @@
 
 #include "login2.h"
 #include "storedProcErrorLookup.h"
+#include "version.h"
 
 #define DEBUG   false
 
-// TODO: XDialog should have a default implementation that returns FALSE
+// TODO: XDialog should have a default implementation that returns false
 bool syncCompanies::userHasPriv(const int pMode)
 {
   if (DEBUG)
@@ -58,7 +59,7 @@ void syncCompanies::setVisible(bool visible)
     XWidget::setVisible(true);
 }
 
-syncCompanies::syncCompanies(QWidget* parent, const char* name, Qt::WFlags fl)
+syncCompanies::syncCompanies(QWidget* parent, const char* name, Qt::WindowFlags fl)
 : XWidget(parent, name, fl)
 {
   setupUi(this);
@@ -234,6 +235,7 @@ void syncCompanies::sSync()
     ParameterList params;
     params.append("databaseURL", dbURL);
     params.append("multipleConnections");
+    params.append("applicationName", _ConnAppName);
 
     login2 newdlg(this, "testLogin", false);
     // disallow changing connection info
