@@ -22,7 +22,7 @@ class syncCompanies : public XWidget, public Ui::syncCompanies
     Q_OBJECT
 
   public:
-    syncCompanies(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    syncCompanies(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~syncCompanies();
 
     static bool userHasPriv(const int = cView);
