@@ -22,7 +22,7 @@ class taxCode : public XDialog, public Ui::taxCode
     Q_OBJECT
 
 public:
-    taxCode(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    taxCode(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~taxCode();
 
 public slots:
