@@ -20,7 +20,7 @@ class taxTypes : public XWidget, public Ui::taxTypes
     Q_OBJECT
 
 public:
-    taxTypes(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    taxTypes(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~taxTypes();
 
 public slots:
