@@ -22,7 +22,7 @@ class todoItem : public XDialog, public Ui::todoItem
     Q_OBJECT
 
 public:
-    todoItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    todoItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
 
     virtual SetResponse set(const ParameterList & pParams );
     virtual void	languageChange();
