@@ -23,7 +23,7 @@ class unpostedPoReceipts : public XWidget, public Ui::unpostedPoReceipts
     Q_OBJECT
 
 public:
-    unpostedPoReceipts(QWidget* parent = 0, const char* name = 0, Qt::WFlags fl = Qt::Window);
+    unpostedPoReceipts(QWidget* parent = 0, const char* name = 0, Qt::WindowFlags fl = Qt::Window);
     ~unpostedPoReceipts();
 
 public slots:
