@@ -20,7 +20,7 @@ class updateItemSiteLeadTimes : public XDialog, public Ui::updateItemSiteLeadTim
     Q_OBJECT
 
 public:
-    updateItemSiteLeadTimes(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    updateItemSiteLeadTimes(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~updateItemSiteLeadTimes();
 
 public slots:
