@@ -20,7 +20,7 @@ class updateLateCustCreditStatus : public XDialog, public Ui::updateLateCustCred
     Q_OBJECT
 
 public:
-    updateLateCustCreditStatus(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    updateLateCustCreditStatus(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~updateLateCustCreditStatus();
 
 public slots:
