@@ -20,7 +20,7 @@ class updateListPricesByProductCategory : public XDialog, public Ui::updateListP
     Q_OBJECT
 
 public:
-    updateListPricesByProductCategory(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    updateListPricesByProductCategory(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~updateListPricesByProductCategory();
 
 public slots:
