@@ -20,7 +20,7 @@ class updateOUTLevelByItem : public XDialog, public Ui::updateOUTLevelByItem
     Q_OBJECT
 
 public:
-    updateOUTLevelByItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    updateOUTLevelByItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~updateOUTLevelByItem();
 
 public slots:
