@@ -21,7 +21,7 @@ class userCostingElement : public XDialog, public Ui::userCostingElement
     Q_OBJECT
 
 public:
-    userCostingElement(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    userCostingElement(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~userCostingElement();
 
 public slots:
