@@ -18,13 +18,14 @@
 
 #include "dspInventoryAvailability.h"
 #include "dspSubstituteAvailabilityByItem.h"
+#include "errorReporter.h"
 #include "inputManager.h"
 #include "returnWoMaterialItem.h"
 #include "storedProcErrorLookup.h"
 #include "substituteList.h"
 #include "woMaterialItem.h"
 
-workOrderMaterials::workOrderMaterials(QWidget* parent, const char* name, Qt::WFlags fl)
+workOrderMaterials::workOrderMaterials(QWidget* parent, const char* name, Qt::WindowFlags fl)
     : XWidget(parent, name, fl)
 {
   setupUi(this);
@@ -73,7 +74,7 @@ workOrderMaterials::workOrderMaterials(QWidget* parent, const char* name, Qt::WF
   }
   else
   {
-    _new->setEnabled(FALSE);
+    _new->setEnabled(false);
     connect(_womatl, SIGNAL(itemSelected(int)), _view, SLOT(animateClick()));
   }
 
@@ -144,7 +145,7 @@ void workOrderMaterials::sNew()
   params.append("mode", "new");
   params.append("wo_id", _wo->id());
 
-  woMaterialItem newdlg(this, "", TRUE);
+  woMaterialItem newdlg(this, "", true);
   newdlg.set(params);
   newdlg.exec();
 }
@@ -155,7 +156,7 @@ void workOrderMaterials::sEdit()
   params.append("mode", "edit");
   params.append("womatl_id", _womatl->id());
 
-  woMaterialItem newdlg(this, "", TRUE);
+  woMaterialItem newdlg(this, "", true);
   newdlg.set(params);
   newdlg.exec();
 }
@@ -166,7 +167,7 @@ void workOrderMaterials::sView()
   params.append("mode", "view");
   params.append("womatl_id", _womatl->id());
 
-  woMaterialItem newdlg(this, "", TRUE);
+  woMaterialItem newdlg(this, "", true);
   newdlg.set(params);
   newdlg.exec();
 }
@@ -192,7 +193,7 @@ void workOrderMaterials::sDelete()
         ParameterList params;
         params.append("womatl_id", womatlid);
 
-        returnWoMaterialItem newdlg(omfgThis, "", TRUE);
+        returnWoMaterialItem newdlg(omfgThis, "", true);
         newdlg.set(params);
 
         newdlg.exec();
@@ -238,7 +239,7 @@ void workOrderMaterials::sDelete()
     return;
   }
 
-  omfgThis->sWorkOrderMaterialsUpdated(_wo->id(), _womatl->id(), TRUE);
+  omfgThis->sWorkOrderMaterialsUpdated(_wo->id(), _womatl->id(), true);
 }
 
 void workOrderMaterials::sViewAvailability()
@@ -313,7 +314,7 @@ void workOrderMaterials::sSubstitute()
     params.append("byDate", sub.value("womatl_duedate"));
     params.append("run");
 
-    substituteList substitute(this, "", TRUE);
+    substituteList substitute(this, "", true);
     substitute.set(params);
     int result = substitute.exec();
     if (result != XDialog::Rejected)
@@ -337,7 +338,7 @@ void workOrderMaterials::sSubstitute()
       else if (sub.value("womatl_issuemethod").toString() == "M")
         params.append("issueMethod", "mixed");
 
-      woMaterialItem newdlg(this, "", TRUE);
+      woMaterialItem newdlg(this, "", true);
       newdlg.set(params);
       if (newdlg.exec() != XDialog::Rejected)
       {
@@ -346,7 +347,7 @@ void workOrderMaterials::sSubstitute()
         workSubstitute.bindValue(":womatl_id", womatlid);
         workSubstitute.exec();
 
-        omfgThis->sWorkOrderMaterialsUpdated(_wo->id(), _womatl->id(), TRUE);
+        omfgThis->sWorkOrderMaterialsUpdated(_wo->id(), _womatl->id(), true);
       }
     }
   }
@@ -368,7 +369,10 @@ void workOrderMaterials::sFillList()
   XSqlQuery workFillList;
   if (_wo->isValid())
   {
-    workFillList.prepare( "SELECT womatl_id, *,"
+    workFillList.prepare( "SELECT womatl_id, item_number, uom_name,"
+               "       womatl_qtyfxd, womatl_qtyper, womatl_scrap,"
+               "       womatl_qtyreq, womatl_qtyiss, womatl_qtywipscrap,"
+               "       womatl_duedate, womatl_notes, womatl_ref,"
                "       (item_descrip1 || ' ' || item_descrip2) AS description,"
                "       CASE WHEN (womatl_issuemethod = 'S') THEN :push"
                "            WHEN (womatl_issuemethod = 'L') THEN :pull"
@@ -385,12 +389,12 @@ void workOrderMaterials::sFillList()
                "       'qty' AS balance_xtnumericrole,"
                "       CASE WHEN (womatl_duedate <= CURRENT_DATE) THEN 'expired'"
                "       END AS womatl_duedate_qtforegroundrole "
-               "FROM wo, womatl, itemsite, item, uom "
-               "WHERE ( (womatl_wo_id=wo_id)"
-               " AND (womatl_uom_id=uom_id)"
-               " AND (womatl_itemsite_id=itemsite_id)"
-               " AND (itemsite_item_id=item_id)"
-               " AND (wo_id=:wo_id) ) "
+               "  FROM wo"
+               "  JOIN womatl   ON (wo_id=womatl_wo_id)"
+               "  JOIN itemsite ON (womatl_itemsite_id=itemsite_id)"
+               "  JOIN item     ON (itemsite_item_id=item_id)"
+               "  JOIN uom      ON (womatl_uom_id=uom_id)"
+               " WHERE (wo_id=:wo_id) "
                "ORDER BY item_number;" );
     workFillList.bindValue(":wo_id", _wo->id());
     workFillList.bindValue(":push",  tr("Push"));
@@ -399,9 +403,9 @@ void workOrderMaterials::sFillList()
     workFillList.bindValue(":error", tr("Error"));
     workFillList.exec();
     _womatl->populate(workFillList);
-    if (workFillList.lastError().type() != QSqlError::NoError)
+    if (ErrorReporter::error(QtCriticalMsg, this, tr("Getting Materials"),
+                             workFillList, __FILE__, __LINE__))
     {
-      systemError(this, workFillList.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
 
@@ -415,8 +419,8 @@ void workOrderMaterials::sFillList()
                "GROUP BY item_picklist;" );
     workFillList.bindValue(":wo_id", _wo->id());
     workFillList.exec();
-    bool   foundPick    = FALSE;
-    bool   foundNonPick = FALSE;
+    bool   foundPick    = false;
+    bool   foundNonPick = false;
     int    totalNumber  = 0;
     double totalQtyPer  = 0.0;
     while (workFillList.next())
@@ -426,20 +430,20 @@ void workOrderMaterials::sFillList()
 
       if (workFillList.value("item_picklist").toBool())
       {
-        foundPick = TRUE;
+        foundPick = true;
         _pickNumber->setText(workFillList.value("total").toDouble());
         _pickQtyPer->setText(formatQtyPer(workFillList.value("qtyper").toDouble()));
       }
       else
       {
-        foundNonPick = TRUE;
+        foundNonPick = true;
         _nonPickNumber->setText(workFillList.value("total").toDouble());
         _nonPickQtyPer->setText(formatQtyPer(workFillList.value("qtyper").toDouble()));
       }
     }
-    if (workFillList.lastError().type() != QSqlError::NoError)
+    if (ErrorReporter::error(QtCriticalMsg, this, tr("Getting Pick Info"),
+                             workFillList, __FILE__, __LINE__))
     {
-      systemError(this, workFillList.lastError().databaseText(), __FILE__, __LINE__);
       return;
     }
 
