@@ -23,7 +23,7 @@ class XDateInputDialog : public XDialog, public Ui::XDateInputDialog
     Q_OBJECT
 
 public:
-    XDateInputDialog(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    XDateInputDialog(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~XDateInputDialog();
     QDate getDate();
 
