@@ -19,7 +19,7 @@ class zeroUncountedCountTagsByWarehouse : public XDialog, public Ui::zeroUncount
     Q_OBJECT
 
 public:
-    zeroUncountedCountTagsByWarehouse(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    zeroUncountedCountTagsByWarehouse(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~zeroUncountedCountTagsByWarehouse();
 
 protected slots:
