@@ -50,19 +50,19 @@ QScriptValue constructQByteArray(QScriptContext *context,
 
   else if (context->argumentCount() == 1 &&
            context->argument(0).isString())
-    obj = new QByteArray(context->argument(0).toString().toAscii().data());
+    obj = new QByteArray(context->argument(0).toString().toLatin1().data());
 
   else if (context->argumentCount() == 2 &&
            context->argument(0).isString() &&
            context->argument(1).isNumber())
-    obj = new QByteArray(context->argument(0).toString().toAscii().data(),
+    obj = new QByteArray(context->argument(0).toString().toLatin1().data(),
                          context->argument(1).toInt32());
 
   else if (context->argumentCount() == 2 &&
            context->argument(0).isNumber() &&
            context->argument(1).isString())
     obj = new QByteArray(context->argument(0).toInt32(),
-                         context->argument(1).toString().at(0).toAscii());
+                         context->argument(1).toString().at(0).toLatin1());
 
   else
     context->throwError(QScriptContext::UnknownError,
