@@ -41,7 +41,7 @@ class XTUPLEWIDGETS_EXPORT ContactList : public VirtualList
   friend class ContactSearch;
 
 public:
-  ContactList(QWidget*, const char* = 0, bool = false, Qt::WFlags = 0);
+  ContactList(QWidget*, const char* = 0, bool = false, Qt::WindowFlags = 0);
   virtual void set(const ParameterList & pParams);
 
 public slots:
