@@ -21,7 +21,7 @@ class imageview : public QDialog, public Ui::imageview
     Q_OBJECT
 
 public:
-    imageview(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WFlags fl = 0);
+    imageview(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
     ~imageview();
 
     QPushButton* _save;
