@@ -17,7 +17,7 @@ IncidentCluster::IncidentCluster(QWidget* pParent, const char* pName) :
 }
 
 IncidentClusterLineEdit::IncidentClusterLineEdit(QWidget* pParent, const char* pName) :
-    CrmClusterLineEdit(pParent, "incdt", "incdt_id", "incdt_number::text", "incdt_summary", 0, "incdt_owner_username", "incdt_assigned_username", 0, pName)
+    CrmClusterLineEdit(pParent, "incdt", "incdt_id", "incdt_number::text", "incdt_summary", "incdt_descrip", "incdt_owner_username", "incdt_assigned_username", 0, pName)
 {
   _objtype = "INCDT";
   setTitles(tr("Incident"), tr("Incidents"));
